==> blanco.plugin.sqleditor_0.3.1-src.zip: blancoSqlEditorPlugin/src/blanco/plugin/sqleditor/BlancoSqlEditorPlugin.java <==
/*
 * blancoSqlEditorPlugin
 * Copyright (C) 2005 sari
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.sqleditor;

import java.util.MissingResourceException;
import java.util.ResourceBundle;

import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

/**
 * BlancoSqlEditorvOC̃NX
 * 
 * @author sari IWił̊J
 * @author Toshiki Iga vOC̉
 */
public class BlancoSqlEditorPlugin extends AbstractUIPlugin {
    // The shared instance.
    private static BlancoSqlEditorPlugin plugin;

    // Resource bundle.
    private ResourceBundle resourceBundle;

    /**
     * The constructor.
     */
    public BlancoSqlEditorPlugin() {
        super();
        plugin = this;
        try {
            resourceBundle = ResourceBundle
                    .getBundle("blanco.plugin.sqleditor.BlancoSqlEditorPluginResources");
        } catch (MissingResourceException x) {
            resourceBundle = null;
        }
    }

    /**
     * This method is called upon plug-in activation
     */
    public void start(BundleContext context) throws Exception {
        super.start(context);
    }

    /**
     * This method is called when the plug-in is stopped
     */
    public void stop(BundleContext context) throws Exception {
        super.stop(context);
    }

    /**
     * Returns the shared instance.
     */
    public static BlancoSqlEditorPlugin getDefault() {
        return plugin;
    }

    /**
     * Returns the string from the plugin's resource bundle, or 'key' if not
     * found.
     */
    public static String getResourceString(String key) {
        ResourceBundle bundle = BlancoSqlEditorPlugin.getDefault()
                .getResourceBundle();
        try {
            return (bundle != null) ? bundle.getString(key) : key;
        } catch (MissingResourceException e) {
            return key;
        }
    }

    /**
     * Returns the plugin's resource bundle,
     */
    public ResourceBundle getResourceBundle() {
        return resourceBundle;
    }
}

==> blanco.plugin.sqleditor_0.3.5-src.zip: blancoSqlEditorPlugin/src/blanco/plugin/sqleditor/BlancoSqlEditorPlugin.java <==
/*
 * blancoSqlEditorPlugin
 * Copyright (C) 2005 sari
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 */
package blanco.plugin.sqleditor;

import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

import blanco.plugin.sqleditor.resourcebundle.BlancoSqlEditorPluginResourceBundle;

/**
 * BlancoSqlEditorvOC̃NX
 * 
 * @author sari IWił̊J
 * @author Toshiki Iga vOC̉
 */
public class BlancoSqlEditorPlugin extends AbstractUIPlugin {
    // The shared instance.
    private static BlancoSqlEditorPlugin plugin;

    // Resource bundle.
    private final BlancoSqlEditorPluginResourceBundle resourceBundle = new BlancoSqlEditorPluginResourceBundle();

    /**
     * The constructor.
     */
    public BlancoSqlEditorPlugin() {
        super();
        plugin = this;
    }

    /**
     * This method is called upon plug-in activation
     */
    public void start(BundleContext context) throws Exception {
        super.start(context);
    }

    /**
     * This method is called when the plug-in is stopped
     */
    public void stop(BundleContext context) throws Exception {
        super.stop(context);
    }

    /**
     * Returns the shared instance.
     */
    public static BlancoSqlEditorPlugin getDefault() {
        return plugin;
    }

    /**
     * Returns the plugin's resource bundle,
     */
    public static BlancoSqlEditorPluginResourceBundle getResourceBundle() {
        return getDefault().resourceBundle;
    }
}
